Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
src / dataknobs_xization / annotations.py |  | 493 | 338 | 122 |  | 31%
src / dataknobs_xization / authorities.py |  | 177 | 112 | 127 |  | 37%
src / dataknobs_xization / content_transformer.py |  | 216 | 196 | 0 |  | 9%
src / dataknobs_xization / ingestion / config.py |  | 120 | 9 | 0 |  | 92%
src / dataknobs_xization / ingestion / processor.py |  | 126 | 14 | 0 |  | 89%
src / dataknobs_xization / json / json_chunker.py |  | 262 | 118 | 0 |  | 55%
src / dataknobs_xization / lexicon.py |  | 213 | 148 | 69 |  | 31%
src / dataknobs_xization / markdown / enrichment.py |  | 61 | 35 | 0 |  | 43%
src / dataknobs_xization / markdown / filters.py |  | 86 | 64 | 2 |  | 26%
src / dataknobs_xization / markdown / md_chunker.py |  | 157 | 53 | 0 |  | 66%
src / dataknobs_xization / markdown / md_parser.py |  | 264 | 174 | 0 |  | 34%
src / dataknobs_xization / markdown / md_streaming.py |  | 63 | 46 | 0 |  | 27%
src / dataknobs_xization / masking_tokenizer.py |  | 293 | 194 | 54 |  | 34%
src / dataknobs_xization / normalize.py |  | 156 | 128 | 0 |  | 18%
Total |  | 2687 | 1629 | 374 |  | 39%

No items found using the specified filter.